local SmokeHouse = ...

-- Apply building asset processor
SmokeHouse:registerAssetProcessor("models/core.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Register core prefab nodes (currently only one core model)
SmokeHouse:registerAssetId("models/core.fbx/Prefab/CoreBuildingPart", SmokeHousePrefix .. "_CORE_BUILDING_PREFAB")

-- Register the Core building part
SmokeHouse:register({
	DataType = "BUILDING_PART",
	Id = SmokeHousePrefix .. "_CORE_BUILDING_PART",
	Name = SmokeHousePrefix .. "_CORE_BUILDING_NAME",
	Description = SmokeHousePrefix .. "_CORE_BUILDING_DESC",
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = SmokeHousePrefix .. "_CORE_BUILDING_PREFAB"
	},
        IsVisibleWhenBuilt = false
})

SmokeHouse:registerAssetId("models/smokehouse.fbx/Materials/carbonRoof", SmokeHousePrefix .. "_CARBON_ROOF_MATERIAL")
SmokeHouse:registerAssetId("models/smokehouse.fbx/Materials/brownRoof", SmokeHousePrefix .. "_BROWN_ROOF_MATERIAL")
SmokeHouse:registerAssetId("models/smokehouse.fbx/Materials/orangeRoof", SmokeHousePrefix .. "_ORANGE_ROOF_MATERIAL")

SmokeHouse:register({
    DataType = "BUILDING",
    Id = SmokeHousePrefix,
    Name = SmokeHousePrefix .. "_NAME",
    Description = SmokeHousePrefix .. "_DESC",
    BuildingType = "GENERAL",
    AssetCoreBuildingPart = SmokeHousePrefix .. "_CORE_BUILDING_PART",
    BuildingPartSetList = {
		{
			Name = SmokeHousePrefix .. "_NAME",
                	BuildingPartList = { SmokeHousePrefix .. "_PART" }
                }
    },
    MaterialSetList = {
            {
                SetName = SmokeHousePrefix .. "_CARBON_ROOF", -- default materials
                MaterialList = {
                    SmokeHousePrefix .. "_CARBON_ROOF_MATERIAL"
                }           
            },
            {
                SetName = SmokeHousePrefix .. "_BROWN_ROOF",
                MaterialList = {
                    SmokeHousePrefix .. "_BROWN_ROOF_MATERIAL"
                }           
            },
            {
                SetName = SmokeHousePrefix .. "_ORANGE_ROOF",
                MaterialList = {
                    SmokeHousePrefix .. "_ORANGE_ROOF_MATERIAL"
                }           
            }
    }
})

SmokeHouse:register({
		DataType = "BUILDING_FUNCTION_ASSIGNABLE",
                Id = SmokeHousePrefix .. "_ASSIGNABLE_FUNCTION",
                AuthorizedFunctionList = SmokeHousePrefix .. "_FUNCTION_LIST"
})

SmokeHouse:register({
		DataType = "BUILDING_FUNCTION_LIST",
                Id = SmokeHousePrefix .. "_FUNCTION_LIST",
                AssetFunctionList = {
                        SmokeHousePrefix .. "_FISH_FUNCTION",
                        SmokeHousePrefix .. "_BOAR_FUNCTION",
                        SmokeHousePrefix .. "_CARCASS_FUNCTION"                }
})

SmokeHouse:register({
		DataType = "BUILDING_FUNCTION_WORKPLACE",
                Id = SmokeHousePrefix .. "_FISH_FUNCTION",
                Name = SmokeHousePrefix .. "_FISH_FUNCTION_NAME",
		WorkerCapacity = 1,
                RelatedJob = { Job = "FISHERMAN", Behavior = "BEHAVIOR_WORK" },
                InputInventoryCapacity = {
			{ Resource = "FISH", Quantity = 50 },
                	{ Resource = SaltPrefix .. "_SALT", Quantity = 50 },
                	{ Resource = "WOOD", Quantity = 50 }
                },
                ResourceListNeeded = {
                	{ Resource = "FISH", Quantity = 1 },
                	{ Resource = SaltPrefix .. "_SALT", Quantity = 1 },
                	{ Resource = "WOOD", Quantity = 1 }
                },
                ResourceProduced = {
			{ Resource = SmokeHousePrefix .. "_SALTING", Quantity = 1 }
                }
})

SmokeHouse:register({
		DataType = "BUILDING_FUNCTION_WORKPLACE",
                Id = SmokeHousePrefix .. "_BOAR_FUNCTION",
                Name = SmokeHousePrefix .. "_BOAR_FUNCTION_NAME",
		WorkerCapacity = 1,
                RelatedJob = { Job = "HUNTER", Behavior = "BEHAVIOR_WORK" },
                InputInventoryCapacity = {
			{ Resource = "BOAR", Quantity = 50 },
                	{ Resource = SaltPrefix .. "_SALT", Quantity = 50 },
                	{ Resource = "WOOD", Quantity = 50 }
                },
                ResourceListNeeded = {
                	{ Resource = "BOAR", Quantity = 1 },
                	{ Resource = SaltPrefix .. "_SALT", Quantity = 1 },
                	{ Resource = "WOOD", Quantity = 1 }
                },
                ResourceProduced = {
			{ Resource = SmokeHousePrefix .. "_SALTING", Quantity = 1 }
                }
})

SmokeHouse:register({
		DataType = "BUILDING_FUNCTION_WORKPLACE",
                Id = SmokeHousePrefix .. "_CARCASS_FUNCTION",
                Name = SmokeHousePrefix .. "_CARCASS_FUNCTION_NAME",
		WorkerCapacity = 1,
                RelatedJob = { Job = "SHEPHERD", Behavior = "BEHAVIOR_WORK" },
                InputInventoryCapacity = {
			{ Resource = CommonResourceCarcass, Quantity = 50 },
                	{ Resource = SaltPrefix .. "_SALT", Quantity = 50 },
                	{ Resource = "WOOD", Quantity = 50 }
                },
                ResourceListNeeded = {
                	{ Resource = CommonResourceCarcass, Quantity = 1 },
                	{ Resource = SaltPrefix .. "_SALT", Quantity = 1 },
                	{ Resource = "WOOD", Quantity = 1 }
                },
                ResourceProduced = {
			{ Resource = SmokeHousePrefix .. "_SALTING", Quantity = 1 }
                }
})

-- Register prefab nodes (currently only one core model)
SmokeHouse:registerAssetId("models/smokehouse.fbx/Prefab/smokeHousePart", SmokeHousePrefix .. "_PREFAB")

-- Register the smoke house part
SmokeHouse:register({
	DataType = "BUILDING_PART",
	Id = SmokeHousePrefix .. "_PART",
	Name = SmokeHousePrefix .. "_NAME",
	Description = SmokeHousePrefix .. "_DESC",
	Category = "CORE",
        BuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {8, 8} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }},
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = SmokeHousePrefix .. "_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = _NoSandbox*1 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "PLANK", Quantity = _NoSandbox*10 }
		}
	},
        VillagerCapacity = 1,
  	AssetBuildingFunction = SmokeHousePrefix .. "_ASSIGNABLE_FUNCTION"
})

-- Register air vent particle system
SmokeHouse:registerAssetId("models/smokehouse.fbx/Prefab/smokeHousePart/step_2/cheminee/SmokeEmitter", SmokeHousePrefix .. "_EMITTER_PREFAB")
 
SmokeHouse:registerPrefabComponent("models/smokehouse.fbx/Prefab/smokeHousePart", {
	DataType = "COMP_BUILDING_PART",
	FeedbackComponentListToActivate = {
                 { SmokeHousePrefix .. "_EMITTER_PREFAB", "COMP_PARTICLE_EMITTER_TOGGLE" }
	}
})

SmokeHouse:registerPrefabComponent("models/smokehouse.fbx/Prefab/smokeHousePart/step_2/cheminee/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "PARTICLE_SYSTEM_HOUSING_SMOKE",
	IsPlaying = true,
	IsEmitting = false
})

SmokeHouse:registerPrefabComponent("models/smokehouse.fbx/Prefab/smokeHousePart/step_2/cheminee/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
})
